# A-TOAD-EMO

![CI](https://github.com/BlancJH/A-Toad-Emo/actions/workflows/ci.yml/badge.svg)
![GitHub release](https://img.shields.io/github/v/tag/BlancJH/A-Toad-Emo)

![Alt Text](assets/images/a-toad-emo.png)

## TODO:
Test v0.1.9
